==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-faq-light/dictionaries/es_cr.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 *
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', [
	'Brick:Portal:FAQ:Menu' => 'Preguntas y Respuestas',
	'Brick:Portal:FAQ:Title' => 'Preguntas y Respuestas Frecuentes',
	'Brick:Portal:FAQ:Title+' => '<p>¿En una prisa?</p><p>Vea la lista de las preguntas más comunes y encontrará (tal vez) la respuesta inmediata a sus necesidades.</p>',
	'Class:FAQ' => 'Preguntas y Respuestas Frecuentes',
	'Class:FAQ+' => 'Preguntas y Respuestas Frecuentes',
	'Class:FAQ/Attribute:category_id' => 'Categoría',
	'Class:FAQ/Attribute:category_id+' => 'Categoría',
	'Class:FAQ/Attribute:category_name' => 'Categoría',
	'Class:FAQ/Attribute:category_name+' => 'Categoría',
	'Class:FAQ/Attribute:description' => 'Descripción',
	'Class:FAQ/Attribute:description+' => 'Descripción',
	'Class:FAQ/Attribute:domains' => 'Ámbito',
	'Class:FAQ/Attribute:error_code' => 'Código de Error',
	'Class:FAQ/Attribute:error_code+' => 'Código de Error',
	'Class:FAQ/Attribute:key_words' => 'Palabras Clave',
	'Class:FAQ/Attribute:key_words+' => 'Palabras Clave',
	'Class:FAQ/Attribute:summary' => 'Resumen',
	'Class:FAQ/Attribute:summary+' => 'Resumen',
	'Class:FAQ/Attribute:title' => 'Asunto',
	'Class:FAQ/Attribute:title+' => 'Asunto',
	'Class:FAQCategory' => 'Categoría de Preguntas y Respuesta Frecuentes',
	'Class:FAQCategory+' => 'Categoría de Preguntas y Respuesta Frecuentes',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQs',
	'Class:FAQCategory/Attribute:faq_list+' => 'FAQs',
	'Class:FAQCategory/Attribute:name' => 'Nombre',
	'Class:FAQCategory/Attribute:name+' => 'Nombre de Categoría de Preguntas y Respuestas Frecuentes',
	'Menu:FAQ' => 'Preguntas y Respuestas Frecuentes',
	'Menu:FAQ+' => 'Preguntas y Respuestas Frecuentes',
	'Menu:FAQCategory' => 'Categorías de FAQ',
	'Menu:FAQCategory+' => 'Categorías FAQ',
	'Menu:Problem:Shortcuts' => 'Acceso Rápido',
	'Menu:ProblemManagement' => 'Administración de problemas',
	'Menu:ProblemManagement+' => 'GestAdministraciónión de problemas',
]);

==> iTop-3.2.1-1-16749.zip: web/datamodels/2.x/itop-faq-light/dictionaries/es_cr.dict.itop-faq-light.php <==
<?php
/**
 * Spanish Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 * @notas       Utilizar codificación UTF-8 para mostrar acentos y otros caracteres especiales 
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:FAQ' => 'Preguntas y Respuestas Frecuentes',
	'Class:FAQ+' => 'Preguntas y Respuestas Frecuentes',
	'Class:FAQ/Attribute:title' => 'Asunto',
	'Class:FAQ/Attribute:title+' => 'Asunto',
	'Class:FAQ/Attribute:summary' => 'Resumen',
	'Class:FAQ/Attribute:summary+' => 'Resumen',
	'Class:FAQ/Attribute:description' => 'Descripción',
	'Class:FAQ/Attribute:description+' => 'Descripción',
	'Class:FAQ/Attribute:category_id' => 'Categoría',
	'Class:FAQ/Attribute:category_id+' => 'Categoría',
	'Class:FAQ/Attribute:category_name' => 'Categoría',
	'Class:FAQ/Attribute:category_name+' => 'Categoría',
	'Class:FAQ/Attribute:error_code' => 'Código de Error',
	'Class:FAQ/Attribute:error_code+' => 'Código de Error',
	'Class:FAQ/Attribute:key_words' => 'Palabras Clave',
	'Class:FAQ/Attribute:key_words+' => 'Palabras Clave',
	'Class:FAQ/Attribute:domains' => 'Ámbito',
));

//
// Class: FAQCategory
//

Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Class:FAQCategory' => 'Categoría de Preguntas y Respuesta Frecuentes',
	'Class:FAQCategory+' => 'Categoría de Preguntas y Respuesta Frecuentes',
	'Class:FAQCategory/Attribute:name' => 'Nombre',
	'Class:FAQCategory/Attribute:name+' => 'Nombre de Categoría de Preguntas y Respuestas Frecuentes',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQs',
	'Class:FAQCategory/Attribute:faq_list+' => 'FAQs',
));
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Menu:ProblemManagement' => 'Administración de Problemas',
	'Menu:ProblemManagement+' => 'GestAdministraciónión de problemas',
	'Menu:Problem:Shortcuts' => 'Acceso Rápido',
	'Menu:FAQCategory' => 'Categorías de FAQ',
	'Menu:FAQCategory+' => 'Categorías FAQ',
	'Menu:FAQ' => 'Preguntas y Respuestas Frecuentes',
	'Menu:FAQ+' => 'Preguntas y Respuestas Frecuentes',
	'Brick:Portal:FAQ:Menu' => 'Preguntas y Respuestas',
	'Brick:Portal:FAQ:Title' => 'Preguntas y Respuestas Frecuentes',
	'Brick:Portal:FAQ:Title+' => '<p>¿En una prisa?</p><p>Vea la lista de las preguntas más comunes y encontrará (tal vez) la respuesta inmediata a sus necesidades.</p>',
));
